==> react-native-firestack-2.3.2.tgz: package/android/src/main/java/io/fullstack/firestack/FirestackPackage.java <==
package io.fullstack.firestack;

import android.content.Context;

import com.facebook.react.ReactPackage;
import com.facebook.react.bridge.JavaScriptModule;
import com.facebook.react.bridge.NativeModule;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.uimanager.ViewManager;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class FirestackPackage implements ReactPackage {
    private Context mContext;

    public FirestackPackage(Context ctx) {
        mContext = ctx;
    }
    /**
     * @param reactContext react application context that can be used to create modules
     * @return list of native modules to register with the newly created catalyst instance
     */
    @Override
    public List<NativeModule> createNativeModules(ReactApplicationContext reactContext) {
        List<NativeModule> modules = new ArrayList<>();

        modules.add(new FirestackModule(reactContext, mContext));
        modules.add(new FirestackAuthModule(reactContext));
        modules.add(new FirestackDatabaseModule(reactContext));
        modules.add(new FirestackAnalyticsModule(reactContext));
        modules.add(new FirestackStorageModule(reactContext));
        modules.add(new FirestackCloudMessaging(reactContext));
        return modules;
    }

    /**
     * @return list of JS modules to register with the newly created catalyst instance.
     * <p/>
     * IMPORTANT: Note that only modules that needs to be accessible from the native code should be
     * listed here. Also listing a native module here doesn't imply that the JS implementation of it
     * will be automatically included in the JS bundle.
     */
    @Override
    public List<Class<? extends JavaScriptModule>> createJSModules() {
        return Collections.emptyList();
    }

    /**
     * @param reactContext
     * @return a list of view managers that should be registered with {@link UIManagerModule}
     */
    @Override
    public List<ViewManager> createViewManagers(ReactApplicationContext reactContext) {
        return Collections.emptyList();
    }
}

==> react-native-firestack-2.3.4.tgz: package/android/src/main/java/io/fullstack/firestack/FirestackPackage.java <==
package io.fullstack.firestack;

import android.content.Context;

import com.facebook.react.ReactPackage;
import com.facebook.react.bridge.JavaScriptModule;
import com.facebook.react.bridge.NativeModule;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.uimanager.ViewManager;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class FirestackPackage implements ReactPackage {
    private Context mContext;

    public FirestackPackage() {
    }
    /**
     * @param reactContext react application context that can be used to create modules
     * @return list of native modules to register with the newly created catalyst instance
     */
    @Override
    public List<NativeModule> createNativeModules(ReactApplicationContext reactContext) {
        List<NativeModule> modules = new ArrayList<>();

        modules.add(new FirestackModule(reactContext, reactContext.getBaseContext()));
        modules.add(new FirestackAuthModule(reactContext));
        modules.add(new FirestackDatabaseModule(reactContext));
        modules.add(new FirestackAnalyticsModule(reactContext));
        modules.add(new FirestackStorageModule(reactContext));
        modules.add(new FirestackCloudMessaging(reactContext));
        return modules;
    }

    /**
     * @return list of JS modules to register with the newly created catalyst instance.
     * <p/>
     * IMPORTANT: Note that only modules that needs to be accessible from the native code should be
     * listed here. Also listing a native module here doesn't imply that the JS implementation of it
     * will be automatically included in the JS bundle.
     */
    @Override
    public List<Class<? extends JavaScriptModule>> createJSModules() {
        return Collections.emptyList();
    }

    /**
     * @param reactContext
     * @return a list of view managers that should be registered with {@link UIManagerModule}
     */
    @Override
    public List<ViewManager> createViewManagers(ReactApplicationContext reactContext) {
        return Collections.emptyList();
    }
}
